<?php

/* ------------------------------------------------------------------------- *
 *  Load theme files
/* ------------------------------------------------------------------------- */
if ( ! function_exists( 'sturdy_load' ) ) {

	function sturdy_load() {
		// Load theme languages
		load_theme_textdomain( 'sturdy', get_template_directory().'/languages' );
		
		// Load custom widgets
		load_template( get_template_directory() . '/functions/widgets/blogsetup-tabs.php' );
		load_template( get_template_directory() . '/functions/widgets/blogsetup-video.php' );

		// Load dynamic styles
		load_template( get_template_directory() . '/functions/dynamic-styles.php' );
		
		// Load TGM plugin activation
		load_template( get_template_directory() . '/functions/class-tgm-plugin-activation.php' );

		// Load Customizer
		load_template( get_template_directory() . '/customizer.php' );

	}
}

add_action( 'after_setup_theme', 'sturdy_load' );


/* ------------------------------------------------------------------------- *
 *  Base functionality
/* ------------------------------------------------------------------------- */
	
// Content width
if ( !isset( $content_width ) ) { $content_width = 720; }


/*  Theme setup
/* ------------------------------------ */
if ( ! function_exists( 'sturdy_setup' ) ) {
	
	function sturdy_setup() {
		
		// Enable custom background
		add_theme_support('custom-background');

		// Enable title tag
		add_theme_support( 'title-tag' );
        add_theme_support( 'automatic-feed-links' );
		
		// Enable featured image
		add_theme_support( 'post-thumbnails' );
		
		// Thumbnail sizes
		add_image_size( 'sturdy-thumb-small', 160, 160, true );
		add_image_size( 'sturdy-thumb-medium', 300, 300, true );
		add_image_size( 'sturdy-thumb-large', 720, 340, true );

		// Custom menu areas
		register_nav_menus( array(
			'topbar' 	=> __('Topbar','sturdy'),
			'header' 	=> __('Header','sturdy'),
			'subheader' => __('Subheader','sturdy'),
			'footer' 	=> __('Footer','sturdy')
		) );
	}
	
}
add_action( 'after_setup_theme', 'sturdy_setup' );


/*  Register sidebars
/* ------------------------------------ */	
if ( ! function_exists( 'sturdy_sidebars' ) ) {

	function sturdy_sidebars()	{
		register_sidebar(array( 'name' => __('Primary Sidebar','sturdy'),'id' => 'primary','description' => __('Normal full width sidebar','sturdy'), 'before_widget' => '<div id="%1$s" class="widget %2$s">','after_widget' => '</div>','before_title' => '<h3 class="group"><span>','after_title' => '</span></h3>'));
    	register_sidebar(array( 'name' => __('Secondary Sidebar','sturdy'),'id' => 'secondary','description' => __('Normal full width sidebar','sturdy'), 'before_widget' => '<div id="%1$s" class="widget %2$s">','after_widget' => '</div>','before_title' => '<h3 class="group"><span>','after_title' => '</span></h3>'));
		register_sidebar(array( 'name' => __('Footer 1','sturdy'),'id' => 'footer-1', 'description' => __('Widgetized footer','sturdy'), 'before_widget' => '<div id="%1$s" class="widget %2$s">','after_widget' => '</div>','before_title' => '<h3 class="group"><span>','after_title' => '</span></h3>')); 
		register_sidebar(array( 'name' => __('Footer 2','sturdy'),'id' => 'footer-2', 'description' => __('Widgetized footer','sturdy'), 'before_widget' => '<div id="%1$s" class="widget %2$s">','after_widget' => '</div>','before_title' => '<h3 class="group"><span>','after_title' => '</span></h3>')); 
		register_sidebar(array( 'name' => __('Footer 3','sturdy'),'id' => 'footer-3', 'description' => __('Widgetized footer','sturdy'), 'before_widget' => '<div id="%1$s" class="widget %2$s">','after_widget' => '</div>','before_title' => '<h3 class="group"><span>','after_title' => '</span></h3>')); 
		register_sidebar(array( 'name' => __('Footer 4','sturdy'),'id' => 'footer-4', 'description' => __('Widgetized footer','sturdy'), 'before_widget' => '<div id="%1$s" class="widget %2$s">','after_widget' => '</div>','before_title' => '<h3 class="group"><span>','after_title' => '</span></h3>')); 
 	}
 }

add_action( 'widgets_init', 'sturdy_sidebars' );


/*  Enqueue javascript
/* ------------------------------------ */
if ( ! function_exists( 'sturdy_scripts' ) ) {

	function sturdy_scripts() {

		wp_enqueue_script( 'fitvids', get_template_directory_uri() . '/js/jquery.fitvids.js', array( 'jquery' ),'', true );
		wp_enqueue_script( 'slick', get_template_directory_uri() . '/js/slick.min.js', array( 'jquery' ),'', true );
		wp_enqueue_script( 'matchheight', get_template_directory_uri() . '/js/jquery.matchHeight-min.js', array( 'jquery' ),'', true );
		wp_enqueue_script( 'scripts', get_template_directory_uri() . '/js/scripts.js', array( 'jquery' ),'', true );
 		if ( is_singular() && get_option( 'thread_comments' ) )	{ wp_enqueue_script( 'comment-reply' ); }
	}
}

add_action( 'wp_enqueue_scripts', 'sturdy_scripts' ); 


/*  Enqueue css
/* ------------------------------------ */	
if ( ! function_exists( 'sturdy_styles' ) ) {

	function sturdy_styles() {

		wp_enqueue_style( 'slick', get_template_directory_uri().'/css/slick.css' );
		wp_enqueue_style( 'slick-theme', get_template_directory_uri().'/css/slick-theme.css' );
		wp_enqueue_style( 'font-awesome', get_template_directory_uri().'/fonts/font-awesome.min.css' );
		wp_enqueue_style( 'style', get_stylesheet_uri() );
		wp_enqueue_style( 'responsive', get_template_directory_uri().'/responsive.css' );  

	}
	
}
add_action( 'wp_enqueue_scripts', 'sturdy_styles' );


/*  Enqueue fonts
/* ------------------------------------ */	
if ( ! function_exists( 'sturdy_google_fonts' ) ) {

	function sturdy_google_fonts() {
		wp_enqueue_style( 'wpb-google-fonts', 
		'http://fonts.googleapis.com/css?family=Open+Sans:400,700|McLaren:400|Roboto+Slab:400',
		 false );
   	  }       
	add_action('wp_enqueue_scripts', 'sturdy_google_fonts');
}

/*  Color scheme applicators
/* ------------------------------------------------------------------------- */	

//Energy color scheme 
if ( ! function_exists( 'sturdy_color_scheme_energy' ) ) {


  function sturdy_color_scheme_energy() {
		
	if (get_theme_mod('color_option') == 'color_option_one' && get_theme_mod('edit_scheme') == 0)  :
			
	$schemeone = array(
		'background_color_choice' => '#232323',
		'header_color_choice' => '#e80000',
		'header_font_color_choice' => '#ffffff',
		'subheader_color_choice' => '#f9f9f9',
		'subheader_font_color_choice' => '#000000',
		'topbar_color_choice' => '#000000',
		'topbar_font_color_choice' => '#ffffff',
		'footer_color_choice' => '#e60000',
		'footer_font_color_choice' => '#d1d1d1',
		'category_hover_color_choice' => '#0a0402',
		'category_color_choice' => '#0027b5',
		'post_title_color_choice' => '#00010f',
		'color_option' => 'color_option_one',
		'post_font_choice' => 'Helvetica, Arial',
		'post_font_color_choice' => '#0a0101',
		'post_font_size_choice' => '17px',
		'post_font_weight_choice' => 'normal',
		'menu_font_choice' => 'Helvetica, Arial',
		'menu_font_size_choice' => '12px',
		'menu_font_weight_choice' => 'bold',
		'logo_font_choice' => 'Helvetica, Arial',
		'logo_font_color_choice' => '#ffffff',
		'logo_font_size_choice' => '30px',
		'logo_font_weight_choice' => 'bold',
		'logo_background_width_choice' => '30%',
		'tagline_font_choice' => 'Roboto Slab, Arial',
		'tagline_font_color_choice' => '#ffffff',
		'tagline_font_size_choice' => '19px',
		'tagline_font_weight_choice' => 'normal',
		'homelayout_choice' => 'col-3cm',
		'postslayout_choice' => 'col-3cm',
		'carousel_image_border_color' => '#fff',
		'related_post_display' => 'cats',
		'carousel_post_title_color' => '#fff',
		'carousel_post_title_hover_color' => '#46B2FF',
		'home_image_border_color' => '#000',
		'featured_post_category' => '1',
		'logo_border_color_choice' => '#fff',
		'logo_background_color_choice' => '#e80000'

		);
			
				foreach ($schemeone as $key => $value) {
				set_theme_mod($key, $value);
				
	         	}
	         endif;
       }
    }
add_action( 'customize_save_after', 'sturdy_color_scheme_energy' );


//Calm color scheme
if ( ! function_exists( 'sturdy_color_scheme_calm' ) ) {

  function sturdy_color_scheme_calm() {
		
	if (get_theme_mod('color_option') == 'color_option_two' && get_theme_mod('edit_scheme') == 0)  :
	
			$schemeone = array(
		'background_color_choice' => '#00a9ff',
		'header_color_choice' => '#000000',
		'header_font_color_choice' => '#ffffff',
		'subheader_color_choice' => '#f9f9f9',
		'subheader_font_color_choice' => '#000000',
		'topbar_color_choice' => '#000000',
		'topbar_font_color_choice' => '#ffffff',
		'footer_color_choice' => '#e60000',
		'footer_font_color_choice' => '#d1d1d1',
		'category_hover_color_choice' => '#0a0402',
		'category_color_choice' => '#0027b5',
		'post_title_color_choice' => '#00010f',
		'color_option' => 'color_option_two',
		'post_font_choice' => 'Helvetica, Arial',
		'post_font_color_choice' => '#0a0101',
		'post_font_size_choice' => '17px',
		'post_font_weight_choice' => 'normal',
		'menu_font_choice' => 'Helvetica, Arial',
		'menu_font_size_choice' => '12px',
		'menu_font_weight_choice' => 'bold',
		'logo_font_choice' => 'Helvetica, Arial',
		'logo_font_color_choice' => '#ffffff',
		'logo_font_size_choice' => '30px',
		'logo_font_weight_choice' => 'bold',
		'logo_background_width_choice' => '30%',
		'tagline_font_choice' => 'Roboto Slab, Arial',
		'tagline_font_color_choice' => '#ffffff',
		'tagline_font_size_choice' => '19px',
		'tagline_font_weight_choice' => 'normal',
		'homelayout_choice' => 'col-3cm',
		'postslayout_choice' => 'col-3cm',
		'carousel_image_border_color' => '#ffffff',
		'related_post_display' => 'cats',
		'carousel_post_title_color' => '#fff',
		'carousel_post_title_hover_color' => '#46B2FF',
		'home_image_border_color' => '#000',
		'featured_post_category' => '1',
		'logo_border_color_choice' => '#ffffff',
		'logo_background_color_choice' => ''

				);
			
				foreach ($schemeone as $key => $value) {
				set_theme_mod($key, $value);
				
	         	}
	         endif;
       }
    }
add_action( 'customize_save_after', 'sturdy_color_scheme_calm' );

/*  plugin : TGM activation
/* ------------------------------------ */

function sturdy_admin_styles() {
  echo '<style>
    #setting-error-tgmpa {
      display: block;
      
    } 
  </style>';
}

add_action('admin_head', 'sturdy_admin_styles');

/*  Layout applicator
/* ------------------------------------ */
if ( ! function_exists( 'sturdy_layout_class' ) ) {

	function sturdy_layout_class() {

		// Check for page/post specific layout
		if ( is_page() || is_single() ) {
			// Reset post data
			wp_reset_postdata();
			global $post;
			$layout = get_theme_mod('postslayout_choice','col-3cm');

		
		}
		else $layout = get_theme_mod('homelayout_choice','col-3cm');
		
		// Return layout class
		return $layout;
	}

}

/*  Primary Sidebar
/* ------------------------------------ */

if ( ! function_exists( 'sturdy_sidebar_primary' ) ) {
	
	function sturdy_sidebar_primary() {
		// Default sidebar
		$sidebar = 'primary';


		// Check for page/post specific sidebar
		if ( is_page() || is_single() ) {
			// Reset post data
			wp_reset_postdata();
			global $post;
			// Get meta
			$meta = get_post_meta($post->ID,'_sidebar_primary',true);
			if ( $meta ) { $sidebar = $meta; }
		}

		// Return sidebar
		return $sidebar;
	}
}

/*  Secondary Sidebar
/* ------------------------------------ */
if ( ! function_exists( 'sturdy_sidebar_secondary' ) ) {


	function sturdy_sidebar_secondary() {
		// Default sidebar
		$sidebar = 'secondary';

		// Check for page/post specific sidebar
		if ( is_page() || is_single() ) {
			// Reset post data
			wp_reset_postdata();
			global $post;
			// Get meta
			$meta = get_post_meta($post->ID,'_sidebar_secondary',true);
			if ( $meta ) { $sidebar = $meta; }
		}

		// Return sidebar
		return $sidebar;
	}
	
}

/*  Site name/logo
/* ------------------------------------ */
if ( ! function_exists( 'sturdy_site_title' ) ) {

	function sturdy_site_title() {
 		
 		// Text or image?
		if ( get_theme_mod('logo_image') ) {
			$logo = '<img src="'.get_theme_mod('logo_image').'" alt="'.get_bloginfo('name').'">';
		} else {
			$logo = get_bloginfo('name');
		}
		
		$link = '<a href="'.esc_url(home_url('/')).'" rel="home">'.$logo.'</a>';
		
		// Removes logo background if image is used and applies <p> tag to site title on pages other than the homepage (SEO)
		if ( null == get_theme_mod('logo_image') && (is_front_page() || is_home() ) ) {
			$sitename = '<h1 class="site-title ">'.$link.'</h1>'."\n";
		} elseif ( null !== get_theme_mod('logo_image') && (is_front_page() || is_home() ) ) {
			$sitename = '<h1 class="site-title bg">'.$link.'</h1>'."\n";
		}
		  elseif ( null == get_theme_mod('logo_image') && (!is_front_page() || !is_home() ) ) {
			$sitename = '<p class="site-title">'.$link.'</p>'."\n";
		}
		  elseif ( null !== get_theme_mod('logo_image') && (!is_front_page() || !is_home() ) ) {
			$sitename = '<p class="site-title bg">'.$link.'</p>'."\n";
		}
		return $sitename;
	}

}

/*  Page title
/* ------------------------------------ */
if ( ! function_exists( 'sturdy_page_title' ) ) {

	function sturdy_page_title() {
		global $post;

		$heading = esc_attr( get_post_meta($post->ID,'_heading',true) );
		$subheading = esc_attr( get_post_meta($post->ID,'_subheading',true) );
		$title = $heading?$heading:the_title();
		if($subheading) {
			$title = $title.' <span>'.$subheading.'</span>';
		}

		return $title;
	}

}

/*  Related posts
/* ------------------------------------ */
if ( ! function_exists( 'sturdy_related_posts' ) ) {

	function sturdy_related_posts() {
		wp_reset_postdata();
		global $post;

		// Define shared post arguments
		$args = array(
			'no_found_rows'				=> true,
			'update_post_meta_cache'	=> false,
			'update_post_term_cache'	=> false,
			'ignore_sticky_posts'		=> 1,
			'orderby'					=> 'rand',
			'post__not_in'				=> array($post->ID),
			'posts_per_page'			=> 3
		);
		// Related by categories
		if ( get_theme_mod('related_post_display') == 'cats' ) {
			
			$cats = get_post_meta($post->ID, 'related-cat', true);
			
			if ( !$cats ) {
				$cats = wp_get_post_categories($post->ID, array('fields'=>'ids'));
				$args['category__in'] = $cats;
			} else {
				$args['cat'] = $cats;
			}
		}
		// Related by tags
		if ( get_theme_mod('related_post_display') == 'tags' ) {
		
			$tags = get_post_meta($post->ID, 'related-tag', true);
			
			if ( !$tags ) {
				$tags = wp_get_post_tags($post->ID, array('fields'=>'ids'));
				$args['tag__in'] = $tags;
			} else {
				$args['tag_slug__in'] = explode(',', $tags);
			}
			if ( !$tags ) { $break = true; }
		}
		
		$query = !isset($break)?new WP_Query($args):new WP_Query;
		return $query;
	}
	
}	



/*  Featured posts title shortener
/* ------------------------------------ */
function sturdy_title_limit($length, $replacer = '...') {

 $string = the_title('','',FALSE);
 
 if(strlen($string) > $length)
 
 $string = (preg_match('/^(.*)\W.*$/', substr($string, 0, $length+1), $matches) ? $matches[1] : substr($string, 0, $length)) . $replacer;
 
 echo $string;

}

/* ------------------------------------------------------------------------- *
 *  Filters
/* ------------------------------------------------------------------------- */

/*  Body class
/* ------------------------------------ */
if ( ! function_exists( 'sturdy_body_class' ) ) {

	function sturdy_body_class( $classes ) {
		$classes[] = sturdy_layout_class();
	
		if ( has_nav_menu('topbar') ) {	$classes[] = 'topbar-enabled'; }

		return $classes;
	}
	
}
add_filter( 'body_class', 'sturdy_body_class' );


/*  Excerpt ending
/* ------------------------------------ */
if ( ! function_exists( 'sturdy_excerpt_more' ) ) {

	function sturdy_excerpt_more( $more ) {
    global $post;

    return '...<br /><br /><a href="'. get_permalink($post->ID) . '">'.__('Read More','sturdy').'...</a>';
	}
	
}
add_filter( 'excerpt_more', 'sturdy_excerpt_more', 11 );


/*  Excerpt length
/* ------------------------------------ */

if ( ! function_exists( 'sturdy_excerpt_length' ) ) {

	function sturdy_excerpt_length( $length ) {
		return 40;
	}
	
}
add_filter( 'excerpt_length', 'sturdy_excerpt_length', 12 );


/*  Browser detection body_class() output
/* ------------------------------------ */
if ( ! function_exists( 'sturdy_browser_body_class' ) ) {


	function sturdy_browser_body_class( $classes ) {
		global $is_lynx, $is_gecko, $is_IE, $is_opera, $is_NS4, $is_safari, $is_chrome, $is_iphone;

		if($is_lynx) $classes[] = 'lynx';
		elseif($is_gecko) $classes[] = 'gecko';
		elseif($is_opera) $classes[] = 'opera';
		elseif($is_NS4) $classes[] = 'ns4';
		elseif($is_safari) $classes[] = 'safari';
		elseif($is_chrome) $classes[] = 'chrome';
		elseif($is_IE) {
			$browser = $_SERVER['HTTP_USER_AGENT'];
			$browser = substr( "$browser", 25, 8);
			if ($browser == "MSIE 7.0"  ) {
				$classes[] = 'ie7';
				$classes[] = 'ie';
			} elseif ($browser == "MSIE 6.0" ) {
				$classes[] = 'ie6';
				$classes[] = 'ie';
			} elseif ($browser == "MSIE 8.0" ) {
				$classes[] = 'ie8';
				$classes[] = 'ie';
			} elseif ($browser == "MSIE 9.0" ) {
				$classes[] = 'ie9';
				$classes[] = 'ie';
			} else {
				$classes[] = 'ie';
			}
		}
		else $classes[] = 'unknown';

		if( $is_iphone ) $classes[] = 'iphone';

		return $classes;
	}
}	

add_filter( 'body_class', 'sturdy_browser_body_class' );


/* ------------------------------------------------------------------------- *
 *  Actions
/* ------------------------------------------------------------------------- */


/*  Script for no-js / js class
/* ------------------------------------ */

if ( ! function_exists( 'sturdy_html_js_class' ) ) {

	function sturdy_html_js_class () {
		echo '<script>document.documentElement.className = document.documentElement.className.replace("no-js","js");</script>'. "\n";
	}
	
}
add_action( 'wp_head', 'sturdy_html_js_class', 1 );


/*  IE js header
/* ------------------------------------ */

if ( ! function_exists( 'sturdy_ie_js_header' ) ) {

	function sturdy_ie_js_header () {
		echo '<!--[if lt IE 9]>'. "\n";
		echo '<script src="' . esc_url( get_template_directory_uri() . '/js/ie/html5.js' ) . '"></script>'. "\n";
		echo '<script src="' . esc_url( get_template_directory_uri() . '/js/ie/selectivizr.js' ) . '"></script>'. "\n";
		echo '<![endif]-->'. "\n";
	}
	
}
add_action( 'wp_head', 'sturdy_ie_js_header' );


/*  IE js footer
/* ------------------------------------ */

if ( ! function_exists( 'sturdy_ie_js_footer' ) ) {

	function sturdy_ie_js_footer () {
		echo '<!--[if lt IE 9]>'. "\n";
		echo '<script src="' . esc_url( get_template_directory_uri() . '/js/ie/respond.js' ) . '"></script>'. "\n";
		echo '<![endif]-->'. "\n";
	}
	
}
add_action( 'wp_footer', 'sturdy_ie_js_footer', 20 );	


/*  TGM plugin activation
/* ------------------------------------ */

if ( ! function_exists( 'sturdy_plugins' ) ) {

	function sturdy_plugins() {	
		 		
			// Add the following plugins
			$plugins = array(
				array(
					'name' 				=> __('WP-PageNavi','sturdy'),
					'slug' 				=> 'wp-pagenavi',
					'required'			=> false,
					'force_activation' 	=> false,
					'force_deactivation'=> false,
				),
				array(
					'name' 				=> __('Contact Form 7','sturdy'),
					'slug' 				=> 'contact-form-7',
					'required'			=> false,
					'force_activation' 	=> false,
					'force_deactivation'=> false,
				)
			);	
			tgmpa( $plugins );
		}
	
	}

add_action( 'tgmpa_register', 'sturdy_plugins' );


/*  WP-PageNavi support
/* ------------------------------------ */
if ( ! function_exists( 'sturdy_deregister_styles' ) ) {
function sturdy_deregister_styles() {
	wp_deregister_style( 'wp-pagenavi' );
	}
}
add_action( 'wp_print_styles', 'sturdy_deregister_styles', 100 );


